@@ -1,6 +1,6 @@
 /* aguix.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009,2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -48,6 +48,7 @@ extern "C" {
 /* ChosseBetterStyle is based on an example program I found somewhere
    But there's was no copyright and the orig codepiece also
    doesn't work...
+   seems to be from the book "Xlib Programming Manual: For Version 11 of the X Window System"
 */
 static XIMStyle ChooseBetterStyle( XIMStyle style1, XIMStyle style2 )
 {
@@ -173,14 +174,29 @@ AGUIX::AGUIX( int argc, char **argv, const std::string &classname ) : m_argc( ar
 #endif
 
   m_open_popup_counter = 0;
+  m_popup_ignore_button_release = false;
 
   m_current_xfocus_window = 0;
+
+  m_last_selection_request_atom = None;
+  m_last_selection_request_window = 0;
+
+  m_apply_window_dialog_type = false;
+
+  m_override_xim = false;
+  m_filtered_key_events_in_a_row = 0;
+  m_skip_filter_event = false;
 }
   
 int AGUIX::initX()
 {
   debugmsg("Opening display...");
 
+  if ( getOverrideXIM() ) {
+      debugmsg("Overwrite XIM...");
+      setenv( "XMODIFIERS", "@im=none", 1 );
+  }
+  
   char *displayname=getenv("DISPLAY");
   dsp=XOpenDisplay(displayname);
   if(dsp==NULL) {
@@ -271,6 +287,10 @@ int AGUIX::initX()
   XA_NET_WM_NAME = XInternAtom( dsp, "_NET_WM_NAME", False );
   XA_NET_WM_ICON_NAME = XInternAtom( dsp, "_NET_WM_ICON_NAME", False );
   XA_TARGETS = XInternAtom( dsp, "TARGETS", False );
+  XA_NET_WM_WINDOW_TYPE = XInternAtom( dsp, "_NET_WM_WINDOW_TYPE", False );
+  XA_NET_WM_WINDOW_TYPE_DIALOG = XInternAtom( dsp, "_NET_WM_WINDOW_TYPE_DIALOG", False );
+  XA_NET_WM_WINDOW_TYPE_NORMAL = XInternAtom( dsp, "_NET_WM_WINDOW_TYPE_NORMAL", False );
+  XA_UTF8_STRING = XInternAtom( dsp, "UTF8_STRING", False );
 
   initOK=True;
   return 0;
@@ -601,13 +621,13 @@ Atom *AGUIX::getCloseAtom()
   return &WM_delete_window;
 }
 
-void AGUIX::insertWindow(AWindow *win)
+void AGUIX::insertWindow( AWindow *win, bool change_transient )
 {
   if(win==NULL) return;
   wins.push_back( win );
 
-  if ( win->isTopLevel() == true ) {
-    setTransientWindow( win );
+  if ( win->isTopLevel() == true && change_transient ) {
+      setTransientWindow( win );
   }
 }
 
@@ -621,16 +641,15 @@ void AGUIX::removeWindow(AWindow *win)
   }
 
   wins.remove( win );
+  wins_as_transient_for.remove( win );
+
   if ( win == transientwindow ) {
     AWindow *new_transient_win = NULL;
 
-    for ( wins_cit_t it1 = wins.begin(); it1 != wins.end(); it1++ ) {
-        AWindow *win_id = *it1;
-        if ( win_id->isTopLevel() == true ) {
-            new_transient_win = win_id;
-        }
+    if ( ! wins_as_transient_for.empty() ) {
+        new_transient_win = wins_as_transient_for.back();
     }
-    
+
     setTransientWindow( new_transient_win );
   }
 }
@@ -669,7 +688,17 @@ Message *AGUIX::wait4mess( int mode )
       msgawin = NULL;
       break;
   }
-  if ( XFilterEvent( &LastEvent, ( msgawin != NULL ) ? msgawin->getWindow() : None ) == True ) return NULL;
+  if ( ! m_skip_filter_event &&
+       XFilterEvent( &LastEvent, ( msgawin != NULL ) ? msgawin->getWindow() : None ) == True ) {
+      if ( LastEvent.type == KeyPress ) {
+          m_filtered_key_events_in_a_row++;
+      }
+      return NULL;
+  }
+
+  if ( LastEvent.type == KeyPress ) {
+      m_filtered_key_events_in_a_row = 0;
+  }
 #else
   msgawin = NULL;
 #endif
@@ -836,8 +865,11 @@ Message *AGUIX::wait4mess( int mode )
 	  pastestart=NULL;
 	}
       } else {
-	if(pastestart!=NULL) pastestart->cancelpaste();
-	pastestart=NULL;
+          if ( rerequestCut() ) {
+          } else {
+              if(pastestart!=NULL) pastestart->cancelpaste();
+              pastestart=NULL;
+          }
       }
       break;
     case SelectionRequest:
@@ -858,9 +890,23 @@ Message *AGUIX::wait4mess( int mode )
 			PropModeReplace,
 			(unsigned char*)clipboard_string.c_str(),
 			clipboard_string.length());
+#ifndef DISABLE_UTF8_SUPPORT
+      } else if( LastEvent.xselectionrequest.selection == XA_PRIMARY &&
+                 LastEvent.xselectionrequest.target == XA_UTF8_STRING &&
+                 UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED &&
+                 UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+	XChangeProperty(dsp,
+			ev.xselection.requestor,
+			ev.xselection.property,
+			ev.xselection.target,
+			8,
+			PropModeReplace,
+			(unsigned char*)clipboard_string.c_str(),
+			clipboard_string.length());
+#endif
       } else if ( LastEvent.xselectionrequest.target == XA_TARGETS ) {
           // send the list of supported atoms
-          Atom supported_targets[] = { XA_TARGETS, XA_STRING };
+          Atom supported_targets[] = { XA_TARGETS, XA_STRING, XA_UTF8_STRING };
           XChangeProperty( dsp,
                            ev.xselection.requestor,
                            ev.xselection.property,
@@ -961,6 +1007,19 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
     if ( XEventsQueued( dsp, QueuedAfterFlush ) > 0 ) continue;
     // and check whether we hit a timer limit
 
+    if ( ! getOverrideXIM() &&
+         m_filtered_key_events_in_a_row == 10 ) {
+
+        m_filtered_key_events_in_a_row++;
+
+        tmsg = AGUIX_allocMessage();
+        tmsg->type = ClientMessage;
+        tmsg->specialType = Message::XIMSTUCK;
+      
+        buildAGMessage( tmsg );
+        AGUIX_freeMessage( tmsg );
+    }
+
     // break loop when timer isn't activated
     if ( ! ( ( msgLockElement != NULL ) &&
 	     ( timerEnabled == true ) ) ) {
@@ -1495,6 +1554,9 @@ void AGUIX::cancelCut()
   cutstart=NULL;
   /*  if(cutbuffer!=NULL) _freesafe(cutbuffer);
       cutbuffer=NULL;*/
+
+  m_last_selection_request_atom = None;
+  m_last_selection_request_window = 0;
 }
 
 int AGUIX::startPaste(GUIElement *elem)
@@ -1514,15 +1576,28 @@ const char *AGUIX::getCutBuffer() const
     return clipboard_string.c_str();
 }
 
-void AGUIX::requestCut(Window win)
+void AGUIX::requestCut( Window win, bool fallback )
 {
   Atom myproperty=XInternAtom(dsp,"Worker Paste Property",False);
+
+  Atom string_atom = XA_STRING;
+#ifndef DISABLE_UTF8_SUPPORT
+  if ( ! fallback ) {
+      if ( UTF8::getUTF8Mode() != UTF8::UTF8_DISABLED && UTF8::getCurrentEncoding() == UTF8::ENCODING_UTF8 ) {
+          string_atom = XA_UTF8_STRING;
+      }
+  }
+#endif
+
   XConvertSelection(dsp,
 		    XA_PRIMARY,
-		    XA_STRING,
+		    string_atom,
 		    myproperty,
 		    win,
 		    CurrentTime);
+
+  m_last_selection_request_atom = string_atom;
+  m_last_selection_request_window = win;
 }
 
 void AGUIX::DrawTriangleFilled(Drawable buffer, int px1, int py1, int px2, int py2, int px3, int py3)
@@ -2242,6 +2317,9 @@ void AGUIX::setTransientWindow( AWindow *twin )
       if ( it1 != wins.end() ) {
           // window found
           transientwindow = twin;
+
+          wins_as_transient_for.remove( twin );
+          wins_as_transient_for.push_back( twin );
       }
   }
 }
@@ -2618,6 +2696,14 @@ Atom AGUIX::getAtom( atom_name_t name ) const
             return XA_NET_WM_ICON_NAME;
         case TARGETS_ATOM:
             return XA_TARGETS;
+        case NET_WM_WINDOW_TYPE:
+            return XA_NET_WM_WINDOW_TYPE;
+        case NET_WM_WINDOW_TYPE_DIALOG:
+            return XA_NET_WM_WINDOW_TYPE_DIALOG;
+        case NET_WM_WINDOW_TYPE_NORMAL:
+            return XA_NET_WM_WINDOW_TYPE_NORMAL;
+        case UTF8_STRING:
+            return XA_UTF8_STRING;
     }
     return None;
 }
@@ -2652,6 +2738,14 @@ void AGUIX::checkPopUpWindows( Message *msg )
     //  if there is a popup, get its groupid and close all other popups
     //  if not, close all popups
 
+    if ( m_popup_ignore_button_release == true ) {
+        m_popup_ignore_button_release = false;
+
+        if ( msg->type == ButtonRelease ) {
+            return;
+        }
+    }
+
     PopUpWindow *win_for_msg = NULL;
 
     for ( popup_wins_cit_t it1 = popup_wins.begin();
@@ -2708,6 +2802,11 @@ void AGUIX::xSync()
 void AGUIX::popupOpened()
 {
     m_open_popup_counter++;
+
+    if ( m_open_popup_counter == 1 ) {
+        // first popup opened, so ignore next button release
+        m_popup_ignore_button_release = true;
+    }
 }
 
 void AGUIX::popupClosed()
@@ -2913,3 +3012,39 @@ void AGUIX::getLargestDimensionOfCurrentScreen( int *x, int *y,
     if ( width ) *width = getRootWindowWidth();
     if ( height ) *height = getRootWindowHeight();
 }
+
+bool AGUIX::rerequestCut()
+{
+    if ( m_last_selection_request_atom != XA_STRING ) {
+        // try again for fallback
+        requestCut( m_last_selection_request_window, true );
+        return true;
+    }
+
+    return false;
+}
+
+void AGUIX::setApplyWindowDialogType( bool nv )
+{
+    m_apply_window_dialog_type = nv;
+}
+
+bool AGUIX::getApplyWindowDialogType() const
+{
+    return m_apply_window_dialog_type;
+}
+
+void AGUIX::setOverrideXIM( bool nv )
+{
+    m_override_xim = nv;
+}
+
+bool AGUIX::getOverrideXIM() const
+{
+    return m_override_xim;
+}
+
+void AGUIX::setSkipFilterEvent( bool nv )
+{
+    m_skip_filter_event = true;
+}
