@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2010,2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2010,2012-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -104,7 +104,7 @@ public:
 
   std::string getClassname() const;
   Atom *getCloseAtom();
-  void insertWindow(AWindow *win);
+  void insertWindow( AWindow *win, bool change_transient = false );
   void removeWindow(AWindow *win);
   AGMessage *GetMessage(AWindow *parent);
   AGMessage *WaitMessage(AWindow *parent);
@@ -136,7 +136,8 @@ public:
   int startPaste(GUIElement *elem);
   bool amiOwner() const;
   const char *getCutBuffer() const;
-  void requestCut(Window win);
+    void requestCut( Window win, bool fallback = false );
+    bool rerequestCut();
   void cancelCutPaste(GUIElement *elem);
   bool isDoubleClick(struct timeval *t1,struct timeval *t2) const;
   bool isDoubleClick( Time t1, Time t2 ) const;
@@ -211,7 +212,10 @@ public:
   void drawBorder( Drawable buffer, GC usegc, bool pressed, int x, int y, int w, int h, int topright_space );
   void drawBorder( Drawable buffer, bool pressed, int x, int y, int w, int h, int topright_space );
 
-    typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM, TARGETS_ATOM } atom_name_t;
+    typedef enum { CLOSE_ATOM, NET_WM_NAME_ATOM, NET_WM_ICON_NAME_ATOM, TARGETS_ATOM,
+                   NET_WM_WINDOW_TYPE, NET_WM_WINDOW_TYPE_DIALOG, NET_WM_WINDOW_TYPE_NORMAL,
+                   UTF8_STRING
+    } atom_name_t;
   Atom getAtom( atom_name_t name ) const;
 
   //TODO also convert to AGUIXColor
@@ -245,6 +249,14 @@ public:
      */
     void getLargestDimensionOfCurrentScreen( int *x, int *y,
                                              int *width, int *height );
+
+    void setApplyWindowDialogType( bool nv );
+    bool getApplyWindowDialogType() const;
+
+    void setOverrideXIM( bool nv );
+    bool getOverrideXIM() const;
+
+    void setSkipFilterEvent( bool nv );
 private:
   Display *dsp;
   int scr;
@@ -253,7 +265,11 @@ private:
   Atom WM_delete_window,
       XA_NET_WM_NAME,
       XA_NET_WM_ICON_NAME,
-      XA_TARGETS;
+      XA_TARGETS,
+      XA_NET_WM_WINDOW_TYPE,
+      XA_NET_WM_WINDOW_TYPE_DIALOG,
+      XA_NET_WM_WINDOW_TYPE_NORMAL,
+      XA_UTF8_STRING;
   int m_argc;
   char **m_argv;
   std::string m_classname;
@@ -299,6 +315,8 @@ private:
   std::list<PopUpWindow*> popup_wins;
   typedef std::list<PopUpWindow*>::const_iterator popup_wins_cit_t;
   typedef std::list<PopUpWindow*>::iterator popup_wins_it_t;
+
+  std::list<AWindow*> wins_as_transient_for;
   
   Window groupwin;
   void createGroupWin();
@@ -344,6 +362,7 @@ private:
   void checkPopUpWindows( Message * );
 
   int m_open_popup_counter;
+  bool m_popup_ignore_button_release;
 
   Window m_current_xfocus_window;
 
@@ -355,6 +374,16 @@ private:
     std::list< AWindow *> m_bg_handler_erase_handler;
 
     std::string clipboard_string;
+
+    Atom m_last_selection_request_atom;
+    Window m_last_selection_request_window;
+
+    bool m_apply_window_dialog_type;
+
+    bool m_override_xim;
+    bool m_skip_filter_event;
+
+    int m_filtered_key_events_in_a_row;
 };
 
 #endif
