@@ -1,6 +1,6 @@
 /* stringgadget.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2010,2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2010,2012-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -316,7 +316,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
         agmsg->type=AG_STRINGGADGET_DEACTIVATE;
         agmsg->stringgadget.sg=this;
 	agmsg->stringgadget.ok = false;
-        msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+        msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
       } else {
         if(forbidPosChange==false) {
 	  _aguix->queryPointer(msg->window,&tx,&ty);
@@ -399,7 +399,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CURSORCHANGE;
 		agmsg->stringgadget.sg=this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      }
 	    } else if((msg->key==XK_Left)||
 		      (msg->key==XK_Home)||
@@ -453,7 +453,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CURSORCHANGE;
 		agmsg->stringgadget.sg=this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      }
 	    } else if((msg->key==XK_Delete)||((msg->key==XK_d)&&(keystate==ControlMask))) {
 	      int len=strlen( content.getText() );
@@ -465,14 +465,14 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg = this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      } else if((content.getCursorPos()<len)&&(len>0)) {
                 content.removeRange( content.getCursorPos(), content.getCursorPos() );
 		returnvalue=true;
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg=this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      }
               textRedraw();
 	    } else if((msg->key==XK_BackSpace)||((msg->key==XK_h)&&(keystate==ControlMask))) {
@@ -484,7 +484,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg = this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      } else if(content.getCursorPos()>0) {
                 int prev_char = content.getCursorPos();
                 UTF8::movePosToPrevChar( content.getText(), prev_char );
@@ -499,7 +499,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg=this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      }
               textRedraw();
 	    } else if ( msg->key == XK_Return ) {
@@ -533,7 +533,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      agmsg = AGUIX_allocAGMessage();
 	      agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
 	      agmsg->stringgadget.sg = this;
-              msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+              msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	    }
 	  }
 	}
@@ -551,18 +551,18 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      agmsg->type=AG_STRINGGADGET_DEACTIVATE;
 	      agmsg->stringgadget.sg=this;
 	      agmsg->stringgadget.ok = ( msg->key == XK_Return ) ? true : false;
-              msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+              msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      if(msg->key==XK_Return) {
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_OK;
 		agmsg->stringgadget.sg=this;
                 agmsg->stringgadget.keystate = keystate;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      } else {
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CANCEL;
 		agmsg->stringgadget.sg=this;
-                msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+                msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
 	      }
 	    } else if((msg->key==XK_Right)||
 		      (msg->key==XK_End)||
@@ -639,7 +639,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
       agmsg = AGUIX_allocAGMessage();
       agmsg->type=AG_STRINGGADGET_ACTIVATE;
       agmsg->stringgadget.sg=this;
-      msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+      msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
       if(forbidPosChange==false) {
         _aguix->queryPointer(msg->window,&tx,&ty);
 
@@ -941,7 +941,7 @@ void StringGadget::lostFocus()
     agmsg->type = AG_STRINGGADGET_DEACTIVATE;
     agmsg->stringgadget.sg = this;
     agmsg->stringgadget.ok = false;
-    msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
   }
 }
 
@@ -952,7 +952,7 @@ void StringGadget::gotFocus()
     AGMessage *agmsg = AGUIX_allocAGMessage();
     agmsg->type = AG_STRINGGADGET_ACTIVATE;
     agmsg->stringgadget.sg = this;
-    msgAndCB( std::auto_ptr<AGMessage>( agmsg ) );
+    msgAndCB( std::unique_ptr<AGMessage>( agmsg ) );
   }
 }
 
