@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2006,2008,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -20,7 +20,6 @@
  */
 
 #include "listermode.h"
-#include "normalmode.h"
 #include "worker.h"
 #include "copyop.h"
 #include "copyopwin.hh"
@@ -31,6 +30,8 @@
 #include <aguix/choosebutton.h>
 #include <aguix/cyclebutton.h>
 #include <aguix/button.h>
+#include "copyorder.hh"
+#include "virtualdirmode.hh"
 
 const char *CopyOp::name="CopyOp";
 
@@ -43,7 +44,6 @@ CopyOp::CopyOp() : FunctionProto()
   request_dest=false;
   request_flags=false;
   overwrite=COPYOP_OVERWRITE_NORMAL;
-  fastcopy=COPYOP_NORMALCOPY;
   preserve_attr=true;
   hasConfigure = true;
     m_category = FunctionProto::CAT_FILEOPS;
@@ -64,7 +64,6 @@ CopyOp::duplicate() const
   ta->request_dest=request_dest;
   ta->request_flags=request_flags;
   ta->overwrite=overwrite;
-  ta->fastcopy=fastcopy;
   ta->preserve_attr=preserve_attr;
   return ta;
 }
@@ -91,9 +90,13 @@ CopyOp::run( WPUContext *wpu, ActionMessage *msg )
       startlister=l1;
       endlister = msg->getWorker()->getOtherLister(startlister);
       lm1=startlister->getActiveMode();
-      if(lm1!=NULL)
-        if(lm1->isType("NormalMode")==true)
-          normalmodecopy( msg );
+      if(lm1!=NULL) {
+          if(dynamic_cast< VirtualDirMode * >( lm1 ) ) {
+              normalmodecopy( msg );
+          } else {
+              lm1->not_supported();
+          }
+      }
     }
   } else {
     normalmodecopy( msg );
@@ -122,17 +125,6 @@ CopyOp::save(Datei *fh)
       fh->configPutPair( "overwrite", "normal" );
       break;
   }
-  switch(fastcopy) {
-    case COPYOP_FASTCOPY:
-      fh->configPutPair( "copymode", "fast" );
-      break;
-    case COPYOP_FASTESTCOPY:
-      fh->configPutPair( "copymode", "fastest" );
-      break;
-    default:
-      fh->configPutPair( "copymode", "normal" );
-      break;
-  }
   fh->configPutPairBool( "preserveattr", preserve_attr );
   return true;
 }
@@ -146,35 +138,25 @@ CopyOp::getDescription()
 int
 CopyOp::normalmodecopy( ActionMessage *am )
 {
-  struct NM_copyorder copyorder;
-  NormalMode *nm1=NULL,
-             *nm2=NULL;
-  ListerMode *lm1=NULL;
+  struct copyorder copyorder;
   NM_specialsourceExt *specialsource=NULL;
   bool do_request,cont=true;
-  char *tstr2,*dest=NULL;
+  std::string destination_directory;
+  ListerMode *start_lm = NULL, *dest_lm = NULL;
   
   if(am->mode==am->AM_MODE_DNDACTION) {
-    lm1 = am->dndmsg->getSourceMode();
-    if(lm1==NULL) return 1;
-    if(lm1->isType("NormalMode")!=true) return 1;
-    nm1=(NormalMode*)lm1;
-    lm1 = am->dndmsg->getDestMode();
-    if(lm1!=NULL)
-      if(lm1->isType("NormalMode")==true)
-        nm2=(NormalMode*)lm1;
+      start_lm = am->dndmsg->getSourceMode();
+      if ( start_lm == NULL ) return 1;
+
+      dest_lm = am->dndmsg->getDestMode();
   } else {
-    if(startlister==NULL) return 1;
-    lm1=startlister->getActiveMode();
-    if(lm1==NULL) return 1;
-    if(lm1->isType("NormalMode")!=true) return 1;
-    nm1=(NormalMode*)lm1;
-    if(endlister!=NULL) {
-      lm1=endlister->getActiveMode();
-      if(lm1!=NULL)
-        if(lm1->isType("NormalMode")==true)
-          nm2=(NormalMode*)lm1;
-    }
+      if ( startlister == NULL ) return 1;
+      start_lm = startlister->getActiveMode();
+      if ( start_lm == NULL ) return 1;
+
+      if ( endlister != NULL ) {
+          dest_lm = endlister->getActiveMode();
+      }
   }
   
   if(request_flags==true) {
@@ -187,7 +169,6 @@ CopyOp::normalmodecopy( ActionMessage *am )
     tsame_dir=same_dir;
     trequest_dest=request_dest;
     toverwrite=overwrite;
-    tfastcopy=fastcopy;
     tpreserve_attr=preserve_attr;
   }
   
@@ -196,20 +177,20 @@ CopyOp::normalmodecopy( ActionMessage *am )
     copyorder.ignoreLosedAttr = false;
     // detect what to copy
     if(am->mode==am->AM_MODE_ONLYACTIVE)
-      copyorder.source=copyorder.NM_ONLYACTIVE;
+      copyorder.source=copyorder.COPY_ONLYACTIVE;
     else if(am->mode==am->AM_MODE_DNDACTION) {
       // insert DND-element into list
-      copyorder.source=copyorder.NM_SPECIAL;
+      copyorder.source=copyorder.COPY_SPECIAL;
       copyorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->dndmsg->getFE() );
       copyorder.sources->push_back(specialsource);
     } else if(am->mode==am->AM_MODE_SPECIAL) {
-      copyorder.source=copyorder.NM_SPECIAL;
+      copyorder.source=copyorder.COPY_SPECIAL;
       copyorder.sources=new std::list<NM_specialsourceExt*>;
       specialsource = new NM_specialsourceExt( am->getFE() );
       copyorder.sources->push_back(specialsource);
     } else
-      copyorder.source=copyorder.NM_ALLENTRIES;
+      copyorder.source=copyorder.COPY_ALLENTRIES;
 
     /* now source defined
        next find destination
@@ -223,97 +204,113 @@ CopyOp::normalmodecopy( ActionMessage *am )
        when no destination then also requesting
     */
 
-    do_request=false;
-    if(trequest_dest==true)
-      do_request=true;
-    else if(tsame_dir==true) {
-      const char *tstr = nm1->getCurrentDir();
-      if(tstr!=NULL)
-        dest=dupstring(tstr);
-    } else if(am->mode==am->AM_MODE_DNDACTION) {
-      const char *ddstr = am->dndmsg->getDestDir();
-      if(ddstr!=NULL) dest=dupstring(ddstr);
-      else dest=NULL;
+    do_request = false;
+    if ( trequest_dest == true ) {
+        do_request = true;
+    } else if ( tsame_dir == true ) {
+        destination_directory = start_lm->getCurrentDirectory();
+    } else if ( am->mode == am->AM_MODE_DNDACTION ) {
+        std::string ddstr = am->dndmsg->getDestDir();
+        if ( ! ddstr.empty() ) {
+            destination_directory = ddstr;
+        }
     } else {
-      if(nm2!=NULL) {
-        const char *tstr = nm2->getCurrentDir();
-        if(tstr!=NULL)
-          dest=dupstring(tstr);
-        else
-          do_request=true;
-      } else
-        do_request=true;
+        if ( dest_lm != NULL ) {
+            destination_directory = dest_lm->getCurrentDirectory();
+
+            if ( destination_directory.empty() ) {
+                do_request = true;
+            }
+
+            if ( auto vdm = dynamic_cast< VirtualDirMode * >( dest_lm ) ) {
+                if ( ! destination_directory.empty() && ! vdm->currentDirIsReal() ) {
+                    std::string textstr = AGUIXUtils::formatStringToString( catalog.getLocale( 1002 ),
+                                                                            destination_directory.c_str() );
+                    std::string buttonstr = catalog.getLocale( 629 );
+                    buttonstr += "|";
+                    buttonstr += catalog.getLocale( 8 );
+
+                    int erg = Worker::getRequester()->request( catalog.getLocale( 123 ),
+                                                               textstr.c_str(),
+                                                               buttonstr.c_str() );
+
+                    if ( erg == 1 ) {
+                        do_request = false;
+                        destination_directory.clear();
+                    }
+                }
+            }
+        } else {
+            do_request=true;
+        }
     }
 
-    if(do_request==true) {
-      const char *defdir;
-      if(dest!=NULL) _freesafe(dest);
+    if ( do_request == true ) {
+        std::string default_dir;
+        char *tstr = NULL;
+
+        destination_directory.clear();
       
-      if ( nm2 != NULL ) {
-        defdir = nm2->getCurrentDir();
-        if ( defdir != NULL ) {
-          if ( strlen( defdir ) < 1 )
-            defdir = nm1->getCurrentDir();
+        if ( dest_lm != NULL ) {
+            default_dir = dest_lm->getCurrentDirectory();
+
+            if ( default_dir.empty() ) {
+                default_dir = start_lm->getCurrentDirectory();
+            }
         } else {
-          defdir = nm1->getCurrentDir();
+            default_dir = start_lm->getCurrentDirectory();
         }
-      } else {
-        defdir = nm1->getCurrentDir();
-      }
       
-      if ( requestdest( defdir, &dest ) != 0 ) {
-        _freesafe(dest);
-        dest=NULL;
-      }
+        if ( requestdest( default_dir.c_str(), &tstr ) != 0 ) {
+            destination_directory.clear();
+        } else {
+            destination_directory = tstr;
+            _freesafe( tstr );
+        }
     }
     /* if dest==null nothing to do
        otherwise: */
-    if(dest!=NULL) {
-      /* if dest starts with no slash then take it as local dir
-         so add currentDir */
-      if(dest[0]!='/') {
-        char *tstr=catstring(nm1->getCurrentDir(),"/");
-        tstr2=catstring(tstr,dest);
-        _freesafe(tstr);
-        _freesafe(dest);
-        dest=tstr2;
-      }
-      /* now also destination determined
-         next describing what to do */
-      copyorder.move=tmove;
-      copyorder.follow_symlinks=tfollow_symlinks;
-      copyorder.preserve_attr=tpreserve_attr;
-      copyorder.do_rename=trename;
-      switch(toverwrite) {
-        case COPYOP_OVERWRITE_ALWAYS:
-          copyorder.overwrite=copyorder.NM_OVERWRITE_ALWAYS;
-          break;
-        case COPYOP_OVERWRITE_NEVER:
-          copyorder.overwrite=copyorder.NM_OVERWRITE_NEVER;
-          break;
-        default:
-          copyorder.overwrite=copyorder.NM_OVERWRITE_NORMAL;
-      }
-      switch(tfastcopy) {
-        case COPYOP_FASTCOPY:
-          copyorder.copymode=copyorder.NM_COPYMODE_NODATABASE;
-          break;
-        default:
-          copyorder.copymode=copyorder.NM_COPYMODE_NORMAL;
-          break;
-      }
-      copyorder.destdir=dest;
-      // now start copy process
-      copyorder.cowin=new CopyOpWin( am->getWorker()->getAGUIX(),
-                                     copyorder.move );
-      nm1->copy(&copyorder);
-      delete copyorder.cowin;
+    if ( ! destination_directory.empty() ) {
+        /* if dest starts with no slash then take it as local dir
+           so add currentDir */
+        if ( destination_directory[0] != '/' ) {
+            std::string tstr = start_lm->getCurrentDirectory();
+
+            destination_directory = tstr + "/" + destination_directory;
+        }
+        /* now also destination determined
+           next describing what to do */
+        copyorder.move=tmove;
+        copyorder.follow_symlinks=tfollow_symlinks;
+        copyorder.preserve_attr=tpreserve_attr;
+        copyorder.do_rename=trename;
+        switch(toverwrite) {
+            case COPYOP_OVERWRITE_ALWAYS:
+                copyorder.overwrite=copyorder.COPY_OVERWRITE_ALWAYS;
+                break;
+            case COPYOP_OVERWRITE_NEVER:
+                copyorder.overwrite=copyorder.COPY_OVERWRITE_NEVER;
+                break;
+            default:
+                copyorder.overwrite=copyorder.COPY_OVERWRITE_NORMAL;
+        }
+        copyorder.destdir = destination_directory.c_str();
+        // now start copy process
+        copyorder.cowin=new CopyOpWin( am->getWorker()->getAGUIX(),
+                                       copyorder.move );
+
+        if ( VirtualDirMode *vdm = dynamic_cast< VirtualDirMode * >( start_lm ) ) {
+            vdm->copy( &copyorder );
+        }
+
+        delete copyorder.cowin;
     }
-    if(dest!=NULL) _freesafe(dest);
-    if(copyorder.source==copyorder.NM_SPECIAL) {
+
+    if(copyorder.source==copyorder.COPY_SPECIAL) {
       if ( specialsource != NULL ) delete specialsource;
       delete copyorder.sources;
     }
+
   }
   return 0;
 }
@@ -325,12 +322,10 @@ CopyOp::doconfigure(int mode)
   AWindow *win;
   ChooseButton *fscb,*mcb,*rcb,*sdcb,*rfcb=NULL,*rdcb,*pacb;
 //  CycleButton *ocyb,*fccyb;
-  CycleButton *fccyb;
   AGMessage *msg;
   int endmode=-1;
   Requester *req;
   char *tstr;
-  int i;
   const int cincw = AContainer::ACONT_MINH +
                     AContainer::ACONT_MINW +
                     AContainer::ACONT_MAXH;
@@ -345,11 +340,11 @@ CopyOp::doconfigure(int mode)
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(8))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(8));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr );
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 10 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 9 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -397,36 +392,12 @@ CopyOp::doconfigure(int mode)
   if(tw>w) w=tw;
   x=5;*/
 
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 7 );
-  ac1_1->setMinSpace( 5 );
-  ac1_1->setMaxSpace( 5 );
-  ac1_1->setBorderWidth( 0 );
-
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 307 ), 1 ), 0, 0, cfix );
-  fccyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
-  fccyb->addOption(catalog.getLocale(308));
-  fccyb->addOption(catalog.getLocale(309));
-//  fccyb->addOption("schnellster Modus");
-  fccyb->resize(fccyb->getMaxSize(),fccyb->getHeight());
-  switch(fastcopy) {
-    case COPYOP_FASTCOPY:
-      fccyb->setOption(1);
-      break;
-/*    case COPYOP_FASTESTCOPY:
-      fccyb->setOption(2);
-      break;*/
-    default:
-      fccyb->setOption(0);
-      break;
-  }
-  ac1_1->readLimits();
-  
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_flags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 8, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 7, cincwnr );
   }
 
-  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 9 );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( -1 );
   ac1_2->setBorderWidth( 0 );
@@ -485,9 +456,6 @@ CopyOp::doconfigure(int mode)
                 ocyb->setOption(i);
                 break;
               case XK_7:*/
-                i=fccyb->getSelectedOption()+1;
-                if(i>=2) i=0;
-                fccyb->setOption(i);
                 break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
@@ -527,17 +495,6 @@ CopyOp::doconfigure(int mode)
           toverwrite=COPYOP_OVERWRITE_NORMAL;
           break;
       }*/
-      switch(fccyb->getSelectedOption()) {
-        case 1:
-          tfastcopy=COPYOP_FASTCOPY;
-          break;
-/*        case 2:
-          tfastcopy=COPYOP_FASTESTCOPY;
-          break;*/
-        default:
-          tfastcopy=COPYOP_NORMALCOPY;
-          break;
-      }
     } else {
       // store in normal variables
       follow_symlinks = fscb->getState();
@@ -559,17 +516,6 @@ CopyOp::doconfigure(int mode)
           overwrite=COPYOP_OVERWRITE_NORMAL;
           break;
       }*/
-      switch(fccyb->getSelectedOption()) {
-        case 1:
-          fastcopy=COPYOP_FASTCOPY;
-          break;
-/*        case 2:
-          fastcopy=COPYOP_FASTESTCOPY;
-          break;*/
-        default:
-          fastcopy=COPYOP_NORMALCOPY;
-          break;
-      }
     }
   }
   
@@ -648,8 +594,3 @@ void CopyOp::setPreserveAttr(bool nv)
 {
   preserve_attr=nv;
 }
-
-void CopyOp::setFastcopy( fastcopy_t nv )
-{
-  fastcopy = nv;
-}
