@@ -1,6 +1,6 @@
 /* copyopwin.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2006,2010-2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -45,7 +45,6 @@ CopyOpWin::CopyOpWin( AGUIX*taguix, bool _move )
   files=0;
   copied_dirs=0;
   dirs=0;
-  slim=false;
   
   window=NULL;
   melw = 0;
@@ -88,20 +87,20 @@ CopyOpWin::~CopyOpWin()
 }
 
 int
-CopyOpWin::open(bool tslim)
+CopyOpWin::open()
 {
   int w,h;
   int tx,ty;
   Text *ttext;
 
   close();
-  this->slim=tslim;
   w=400;
   h=10;
   window = new AWindow( aguix,
 			10, 10,
 			w, h,
-			0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
+			0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+                        AWindow::AWINDOW_DIALOG );
   window->create();
   tx=5;
   ty=5;
@@ -129,34 +128,30 @@ CopyOpWin::open(bool tslim)
   bb2=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb2->getHeight()+5;
 
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale((slim==true)?284:118),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(118),1));
   tx+=ttext->getWidth()+5;
   files2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
   tx=5;
   ty+=ttext->getHeight()+5;
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale((slim==true)?285:119),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(119),1));
   tx+=ttext->getWidth()+5;
   dirs2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
   tx=5;
   ty+=ttext->getHeight()+5;
-  if(slim==false) {
-    gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"",2,3,0));
-    bb3=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,gsb->getHeight()+2,1));
-    gsb->toFront();
-    ty+=bb3->getHeight()+5;
-  }
+  gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"",2,3,0));
+  bb3=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,gsb->getHeight()+2,1));
+  gsb->toFront();
+  ty+=bb3->getHeight()+5;
   tx=10;
   ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(120),1));
   tx+=ttext->getWidth()+5;
   globtext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
   tx=5;
   ty+=globtext->getHeight()+5;
-  if(slim==false) {
-    ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(121),1));
-    tx+=ttext->getWidth()+5;
-    timetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
-    ty+=timetext->getHeight()+5;
-  }
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(121),1));
+  tx+=ttext->getWidth()+5;
+  timetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  ty+=timetext->getHeight()+5;
   tx=5;
   bb4=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb4->getHeight()+5;
@@ -449,28 +444,18 @@ CopyOpWin::redraw()
                                                                   AGUIXUtils::BM_SYSTEM_SETTING,
                                                                   rate );
 
-        if(slim==true) {
-            snprintf( tstr, sizeof( tstr ), "%s @ %s/s", copied_bytes_str.c_str(), AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
-            tstr[ sizeof( tstr ) - 1 ] = '\0';
-        } else {
-            bytes_str = AGUIXUtils::bytes_to_human_readable_f( (double)bytes,
-                                                               1, ( rate > 0.0 ) ? 5 : 0,
-                                                               AGUIXUtils::BM_SYSTEM_SETTING,
-                                                               rate );
+        bytes_str = AGUIXUtils::bytes_to_human_readable_f( (double)bytes,
+                                                           1, ( rate > 0.0 ) ? 5 : 0,
+                                                           AGUIXUtils::BM_SYSTEM_SETTING,
+                                                           rate );
 
-            snprintf( tstr, sizeof( tstr ), "%s / %s @ %s/s", copied_bytes_str.c_str(), bytes_str.c_str(), AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
-            tstr[ sizeof( tstr ) - 1 ] = '\0';
-        }
+        snprintf( tstr, sizeof( tstr ), "%s / %s @ %s/s", copied_bytes_str.c_str(), bytes_str.c_str(), AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
+        tstr[ sizeof( tstr ) - 1 ] = '\0';
     } else {
         MakeLong2NiceStr( copied_bytes, copied_bytes_str );
-        if(slim==true) {
-            snprintf( tstr, sizeof( tstr ), "%s @ %.2f KB/s", copied_bytes_str.c_str(), rate / 1024.0 );
-            tstr[ sizeof( tstr ) - 1 ] = '\0';
-        } else {
-            MakeLong2NiceStr( bytes, bytes_str );
-            snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", copied_bytes_str.c_str(), bytes_str.c_str(), rate / 1024.0 );
-            tstr[ sizeof( tstr ) - 1 ] = '\0';
-        }
+        MakeLong2NiceStr( bytes, bytes_str );
+        snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", copied_bytes_str.c_str(), bytes_str.c_str(), rate / 1024.0 );
+        tstr[ sizeof( tstr ) - 1 ] = '\0';
     }
     
     globtext->setText(tstr);
@@ -480,90 +465,88 @@ CopyOpWin::redraw()
       doresize = true;
     }
     
-    if(slim==false) {
-        int rate_precision = AGUIXUtils::calc_precision( rate * 100.0 / (double)bytes );
-        if ( rate_precision < 0 ) rate_precision = 0;
+    int rate_precision = AGUIXUtils::calc_precision( rate * 100.0 / (double)bytes );
+    if ( rate_precision < 0 ) rate_precision = 0;
 
-      if(bytes>0)
+    if(bytes>0)
         rate = (double)copied_bytes/(double)bytes;
-      else
+    else
         rate=0.0;
-      if ( rate < 0.01 )
+    if ( rate < 0.01 )
         rate = 0.0;
 
-      std::string fraction_str = AGUIXUtils::formatStringToString( "%%.%df %%%%",
-                                                                   rate_precision );
+    std::string fraction_str = AGUIXUtils::formatStringToString( "%%.%df %%%%",
+                                                                 rate_precision );
 
-      snprintf( tstr, sizeof( tstr ), fraction_str.c_str(), rate * 100.0 );
+    snprintf( tstr, sizeof( tstr ), fraction_str.c_str(), rate * 100.0 );
 
-      tstr[ sizeof( tstr ) - 1 ] = '\0';
-      gsb->setText(tstr);
-      gsb->resize( w_max( (int)( sbw * rate ), 2 ), gsb->getHeight() );
+    tstr[ sizeof( tstr ) - 1 ] = '\0';
+    gsb->setText(tstr);
+    gsb->resize( w_max( (int)( sbw * rate ), 2 ), gsb->getHeight() );
       
-      newglob_percent = (int)( rate * 100.0 );
-      if ( newglob_percent != glob_percent ) {
+    newglob_percent = (int)( rate * 100.0 );
+    if ( newglob_percent != glob_percent ) {
         glob_percent = newglob_percent;
         tstr3 = (char*)_allocsafe( strlen( ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) ) +
                                    strlen( " ( %)" ) + 
                                    A_BYTESFORNUMBER( glob_percent ) +
                                    1 );
         if ( ( glob_percent > 0 ) && ( glob_percent <= 100 ) ) {
-          sprintf( tstr3, "%s (%d %%)",
-                   ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
-                   glob_percent );
+            sprintf( tstr3, "%s (%d %%)",
+                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+                     glob_percent );
         } else {
-          sprintf( tstr3, "%s",
-                   ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
+            sprintf( tstr3, "%s",
+                     ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
         }
         window->setTitle( tstr3 );
         _freesafe( tstr3 );
-      }
+    }
       
-      if(rate>0) {
+    if(rate>0) {
         drtime = difftime2 / rate;
         drtime -= difftime2;
         rtime = (long)( drtime / 1000000.0 );
-      } else
+    } else
         rtime = 700000;  // no rate available => no real time calculatable
 
-      if ( lastrate_global != 0.0 ) {
-          double remaining_bytes = (double)bytes - (double)copied_bytes;
-          rtime_at_current_rate = remaining_bytes / lastrate_global;
-          rtime_at_current_rate++;
-      } else {
-          rtime_at_current_rate = 700000;
-      }
+    if ( lastrate_global != 0.0 ) {
+        double remaining_bytes = (double)bytes - (double)copied_bytes;
+        rtime_at_current_rate = remaining_bytes / lastrate_global;
+        rtime_at_current_rate++;
+    } else {
+        rtime_at_current_rate = 700000;
+    }
 
-      rtime++; // add a second because the last second will shown as 0:00
-               // and at least I don't like this
-      if ( rtime > 604800 ) // more then 7 days
+    rtime++; // add a second because the last second will shown as 0:00
+    // and at least I don't like this
+    if ( rtime > 604800 ) // more then 7 days
         sprintf( tstr, "--:--" );
-      else 
+    else 
         sprintf( tstr, "%ld:%02ld", rtime / 60, rtime % 60 );
 
-      if ( rtime_at_current_rate <= 604800 &&
-           fabs( rtime - rtime_at_current_rate ) > 10.0 &&
-           fabs( rtime - rtime_at_current_rate ) / (double)rtime > 0.1 ) {
-          std::string alt_time_str = AGUIXUtils::formatStringToString( catalog.getLocale( 973 ),
-                                                                       tstr,
-                                                                       rtime_at_current_rate / 60,
-                                                                       rtime_at_current_rate % 60 );
-          timetext->setText( alt_time_str.c_str() );
-      } else {
-          timetext->setText(tstr);
-      }
+    if ( rtime_at_current_rate <= 604800 &&
+         fabs( rtime - rtime_at_current_rate ) > 10.0 &&
+         fabs( rtime - rtime_at_current_rate ) / (double)rtime > 0.1 ) {
+        std::string alt_time_str = AGUIXUtils::formatStringToString( catalog.getLocale( 973 ),
+                                                                     tstr,
+                                                                     rtime_at_current_rate / 60,
+                                                                     rtime_at_current_rate % 60 );
+        timetext->setText( alt_time_str.c_str() );
+    } else {
+        timetext->setText(tstr);
+    }
 
-      tw = timetext->getX() + timetext->getWidth() + window->getBorderWidth();
-      if ( tw > melw ) {
+    tw = timetext->getX() + timetext->getWidth() + window->getBorderWidth();
+    if ( tw > melw ) {
         melw = tw;
         doresize = true;
-      }
     }
+
     update_globtext=false;
   }
   if(update_files2gotext==true) {
-    if(slim==true) sprintf(tstr,"%ld",copied_files);
-    else sprintf(tstr,"%ld",files-copied_files);
+    sprintf(tstr,"%ld",files-copied_files);
     files2gotext->setText(tstr);
     tw = files2gotext->getX() + files2gotext->getWidth() + window->getBorderWidth();
     if ( tw > melw ) {
@@ -574,8 +557,7 @@ CopyOpWin::redraw()
     update_files2gotext=false;
   }
   if(update_dirs2gotext==true) {
-    if(slim==true) sprintf(tstr,"%ld",copied_dirs);
-    else sprintf(tstr,"%ld",dirs-copied_dirs);
+    sprintf(tstr,"%ld",dirs-copied_dirs);
     dirs2gotext->setText(tstr);
     tw = dirs2gotext->getX() + dirs2gotext->getWidth() + window->getBorderWidth();
     if ( tw > melw ) {
@@ -614,9 +596,7 @@ CopyOpWin::redraw()
             bb1->resize( msg->size.neww - 2 * window->getBorderWidth(), bb1->getHeight() );
             sbw = bb1->getWidth() - 2;
             bb2->resize( msg->size.neww - 2 * window->getBorderWidth(), bb2->getHeight() );
-            if ( slim == false ) {
-              bb3->resize( msg->size.neww - 2 * window->getBorderWidth(), bb3->getHeight() );
-            }
+            bb3->resize( msg->size.neww - 2 * window->getBorderWidth(), bb3->getHeight() );
             bb4->resize( msg->size.neww - 2 * window->getBorderWidth(), bb4->getHeight() );
             cb->move( msg->size.neww / 2 - cb->getWidth() / 2,
                       msg->size.newh - window->getBorderWidth() - cb->getHeight() );
