@@ -1,6 +1,6 @@
 /* lister.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2009,2011-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2009,2011-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -68,10 +68,9 @@ public:
   void cyclicfunc(cyclicfunc_mode_t mode);
   int saveState(Datei *fh);
   int loadState();
-  int loadBinState(Datei *fh);
   const char *getNameOfMode(int);
   
-  void reconfig();
+  void relayout();
   
   bool startdnd(DNDMsg *dm);
 
