@@ -1,6 +1,6 @@
 /* listermode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2011-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2011-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -94,22 +94,12 @@ int ListerMode::load()
   return 0;
 }
 
-int ListerMode::loadBin(Datei *fh)
-{
-  int chunksize=fh->getInt();
-  while(chunksize>0) {
-    fh->getUChar();
-    chunksize--;
-  }
-  return 0;
-}
-
 bool ListerMode::save(Datei *fh)
 {
   return false;
 }
 
-void ListerMode::reconfig()
+void ListerMode::relayout()
 {
 }
 
@@ -210,3 +200,42 @@ bool ListerMode::pathsChanged( const std::set< std::string > changed_paths )
 {
     return false;
 }
+
+int ListerMode::getSelFiles( std::list< NM_specialsourceExt > &return_list,
+                             lm_getfiles_t get_mode,
+                             bool unselect )
+{
+    return 0;
+}
+
+std::string ListerMode::getCurrentDirectory()
+{
+    return "";
+}
+
+bool ListerMode::deselectEntry( const std::string &filename )
+{
+    return false;
+}
+
+void ListerMode::updateOnBookmarkChange()
+{
+}
+
+void ListerMode::not_supported()
+{
+    parentlister->getWorker()->getRequester()->request( catalog.getLocale( 123 ),
+                                                        catalog.getLocale( 1000 ),
+                                                        catalog.getLocale( 11 ) );
+}
+
+std::list< std::string > ListerMode::getListOfCommandsWithoutArgs()
+{
+    std::list< std::string > res;
+
+    for ( auto &e : m_commands ) {
+        res.push_back( e.first );
+    }
+
+    return res;
+}
