@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2011-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2005,2011-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,6 +27,7 @@
 #include "generic_callback.hh"
 #include <aguix/refcount.hh>
 #include "lister.h"
+#include "nmspecialsourceext.hh"
 #include <map>
 
 class ArgClass;
@@ -52,11 +53,10 @@ public:
   virtual void cyclicfunc(cyclicfunc_mode_t mode);
   virtual const char *getLocaleName();
 
-  virtual int loadBin(Datei*);
   virtual int load();
   virtual bool save(Datei *);
   
-  virtual void reconfig();
+  virtual void relayout();
 /*  static ListerMode *preload(Worker*,Datei*,int side);
   static int presave(Datei*,ListerMode*);*/
   
@@ -73,6 +73,24 @@ public:
     virtual void runCommandWithStrArgs( const std::string &command_str );
 
     virtual bool pathsChanged( const std::set< std::string > changed_paths );
+
+    typedef enum { LM_GETFILES_ONLYACTIVE,
+                   LM_GETFILES_ONLYSELECT,
+                   LM_GETFILES_SELORACT} lm_getfiles_t;
+
+    virtual int getSelFiles( std::list< NM_specialsourceExt > &return_list,
+                             lm_getfiles_t get_mode,
+                             bool unselect = false );
+
+    virtual std::string getCurrentDirectory();
+
+    virtual bool deselectEntry( const std::string &filename );
+
+    virtual void updateOnBookmarkChange();
+
+    virtual void not_supported();
+
+    virtual std::list< std::string > getListOfCommandsWithoutArgs();
 protected:
   Lister *parentlister;
   AGUIX *aguix;
