@@ -1,6 +1,6 @@
 /* nwc_path.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2009-2010,2012 Ralf Hoffmann.
+ * Copyright (C) 2006,2009-2010,2012-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,7 @@
 #include "nwc_path.hh"
 #include "nwc_os.hh"
 #include <aguix/lowlevelfunc.h>
+#include <aguix/util.h>
 
 namespace NWC {
     namespace Path {
@@ -75,6 +76,8 @@ namespace NWC {
             if ( pos == std::string::npos )
                 return std::string( "." );
           
+            if ( pos == 0 ) pos++;
+
             return std::string( path, 0, pos );
         }
 
@@ -310,5 +313,35 @@ namespace NWC {
             return newpath;
         }
 
+        std::string get_extended_basename( const std::string &prefix,
+                                           const std::string &fullname )
+        {
+            if ( prefix.length() >= fullname.length() ) return "";
+
+            // fullname is at least one char longer
+
+            // no prefix?
+            if ( ! AGUIXUtils::starts_with( fullname, prefix ) ) return "";
+
+            std::string res;
+
+            if ( AGUIXUtils::ends_with( prefix, "/" ) ) {
+                // prefix already ends with slash no do not remove another byte
+                res = std::string( fullname, prefix.length() );
+            } else {
+                // there must be a slash after the prefix so it is really a sub-entry
+                if ( fullname[ prefix.length() ] != '/' ) return "";
+
+                // no slash at end of prefix
+                res = std::string( fullname, prefix.length() + 1 );
+            }
+
+            // if result still starts with a slash, there was a problem like
+            // an unnormalized path
+            if ( AGUIXUtils::starts_with( res, "/" ) ) return "";
+
+            return res;
+        }
+
     }
 }
