@@ -1,6 +1,6 @@
 /* textviewmode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011 Ralf Hoffmann.
+ * Copyright (C) 2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,7 +22,6 @@
 #include <aguix/acontainer.h>
 #include <aguix/textview.h>
 #include "textviewmode.hh"
-#include "normalmode.h"
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
@@ -191,7 +190,7 @@ void TextViewMode::setName()
     parentlister->setName( catalog.getLocale( 939 ) );
 }
 
-void TextViewMode::reconfig()
+void TextViewMode::relayout()
 {
     if ( m_tv != NULL ) {
         off();
@@ -201,36 +200,24 @@ void TextViewMode::reconfig()
 
 void TextViewMode::update( bool force )
 {
-    NormalMode *nm1 = NULL;
     ListerMode *lm1 = NULL;
     Lister *ol = NULL;
-    std::list<NM_specialsourceExt*> *files;
-    std::list<NM_specialsourceExt*>::iterator it1;
-    NM_specialsourceExt *ss1;
     const FileEntry *fe;
   
     ol = parentlister->getWorker()->getOtherLister( parentlister );
     if ( ol != NULL ) {
         lm1 = ol->getActiveMode();
-        if ( lm1 != NULL )
-            if ( lm1->isType( "NormalMode" ) == true )
-                nm1 = (NormalMode*)lm1;
     }
   
     if ( force == true )
         clearLastActiveFE();
   
-    if ( nm1 != NULL ) {
-        files = new std::list<NM_specialsourceExt*>;
+    if ( lm1 != NULL ) {
+        std::list< NM_specialsourceExt > files;
     
-        nm1->getSelFiles( files, NormalMode::NM_GETFILES_ONLYACTIVE );
-        if ( files->begin() != files->end() )
-            ss1 = *( files->begin() );
-        else
-            ss1 = NULL;
-
-        if ( ss1 != NULL ) {
-            fe = ss1->entry();
+        lm1->getSelFiles( files, ListerMode::LM_GETFILES_ONLYACTIVE );
+        if ( ! files.empty() ) {
+            fe = files.begin()->entry();
             if ( fe != NULL ) {
                 if ( fe->equals( m_lastactivefe ) == false ) {
                     clearLastActiveFE();
@@ -247,12 +234,6 @@ void TextViewMode::update( bool force )
                 }
             }
         }
-    
-        for ( it1 = files->begin(); it1 != files->end(); it1++ ) {
-            delete *it1;
-        }
-    
-        delete files;
     }
 }
 
