@@ -1,6 +1,6 @@
 /* wcfiletype.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2006-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2006-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -67,6 +67,7 @@ WCFiletype::WCFiletype()
   m_use_magic = false;
   m_magic_pattern = "";
   m_magic_compressed = false;
+  m_magic_mime = false;
 }
 
 int WCFiletype::getinternID() const
@@ -169,6 +170,7 @@ WCFiletype *WCFiletype::duplicate() const
   tft->setUseMagic( m_use_magic );
   tft->setMagicCompressed( m_magic_compressed );
   tft->setMagicPattern( m_magic_pattern );
+  tft->setMagicMime( m_magic_mime );
 
   return tft;
 }
@@ -848,6 +850,10 @@ bool WCFiletype::save(Datei *fh) const
       fh->configPutPairBool( "magiccompressed", m_magic_compressed );
   }
 
+  if ( m_magic_mime == true ) {
+      fh->configPutPairBool( "magicmime", m_magic_mime );
+  }
+
   return true;
 }
 
@@ -991,3 +997,13 @@ bool WCFiletype::magicMatch( const std::string &match_string )
     }
     return m_magic_matcher->match( match_string );
 }
+
+bool WCFiletype::getMagicMime() const
+{
+    return m_magic_mime;
+}
+
+void WCFiletype::setMagicMime( bool nv )
+{
+    m_magic_mime = nv;
+}
