@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -59,6 +59,56 @@ class PersDeepPathStore;
 class HintDB;
 class PathnameWatcher;
 class Slider;
+class MenuTreeUI;
+class MenuTreeNode;
+class WConfig;
+class PersistentKVP;
+class PrefixDB;
+
+class worker_version
+{
+public:
+    worker_version() : m_major( 0 ),
+                       m_minor( 0 ),
+                       m_patch( 0 )
+    {}
+
+    worker_version( int major ,
+                    int minor,
+                    int patch ) : m_major( major ),
+                                  m_minor( minor ),
+                                  m_patch( patch )
+    {}
+
+    bool operator<( const worker_version &rhs ) const
+    {
+        if ( m_major < rhs.m_major ) return true;
+
+        if ( m_major > rhs.m_major ) return false;
+
+        if ( m_minor < rhs.m_minor ) return true;
+
+        if ( m_minor > rhs.m_minor ) return false;
+
+        if ( m_patch < rhs.m_patch ) return true;
+
+        return false;
+    }
+
+    bool operator<=( const worker_version &rhs ) const
+    {
+        return ! ( rhs < *this );
+    }
+
+    bool operator>( const worker_version &rhs ) const
+    {
+        return rhs < *this;
+    }
+
+    int m_major;
+    int m_minor;
+    int m_patch;
+};
 
 class Worker
 {
@@ -160,12 +210,32 @@ public:
     void removePathPers( const std::string &path );
     std::list< std::string > getPathsPers();
 
+    void storePathPersIfInProgress( const std::string &path );
+    void setPathJumpInProgress( bool nv = true );
+    void setPathJumpInProgress( const std::string last_filter );
+
     void copyToClipboard( const std::string &str );
 
     void showNextHint();
 
     RefCount< PathnameWatcher > getPathnameWatcher();
- protected:
+
+    bool checkEnterDir( const std::string &dir );
+
+    static mode_t getUMask();
+
+    void openCommandMenu();
+
+    worker_version getLastRunningVersion();
+    void checkForUpdates( const worker_version &last_running_version,
+                          WConfig *conf );
+
+    void setOverrideXIM( bool nv );
+
+    static PersistentKVP &getKVPStore();
+
+    PrefixDB &getDirHistPrefixDB();
+protected:
   void createMainWin();
   void setupMainWin();
   void closeMainWin();
@@ -179,6 +249,8 @@ public:
   void setPath( WCPath *);
   int activateShortkey(AGMessage*);
   void activateButton(int,int,int);
+    void activateButton( int pos );
+    void activateHotkey( int pos );
   int saveListerState();
   int initListerState();
   void updateTime();
@@ -253,7 +325,7 @@ public:
   int m_interpret_recursion_depth;
   static const int m_interpret_max_recursion = 1000;
 
-  static std::auto_ptr<BookmarkDBProxy> m_bookmarkproxy;
+  static std::unique_ptr<BookmarkDBProxy> m_bookmarkproxy;
 
   std::map<const PopUpMenu *, std::list< RefCount<GenericCallbackArg<void, AGMessage*> > > > m_popup_callbacks;
 
@@ -325,14 +397,45 @@ public:
 
     void updateHintDB();
 
+    void prepareMenuTree( MenuTreeUI &menuui );
+    void initWorkerTextMenu( MenuTreeNode *menu );
+    bool checkCommandListForCommand( List *list, const std::string &name );
+
+    void updateRunningVersion();
+
+    bool importUpdate( WConfig *baseconfig,
+                       const std::pair< worker_version, std::string > &config_entry );
+
+    void switchCurrentMode( int mode );
+    void configureCurrentMode();
+
+    std::string getOverrideXIMPath() const;
+
     DeepPathStore m_path_store;
-    std::auto_ptr< PersDeepPathStore > m_pers_path_store;
+    std::unique_ptr< PersDeepPathStore > m_pers_path_store;
 
     std::string m_current_hint;
     time_t m_hint_time;
     RefCount< HintDB > m_hint_db;
     RefCount< PathnameWatcher > m_pathname_watcher;
     std::set< std::string > m_changed_paths;
+
+    enum ssh_allow_t { SSH_ASK, SSH_NEVER, SSH_ALWAYS } m_ssh_allow;
+
+    static mode_t m_process_umask;
+
+    RefCount< MenuTreeUI > m_menu_ui;
+    bool m_menu_active;
+
+    int m_commandmenu_original_button_banknr;
+    int m_commandmenu_original_path_banknr;
+
+    static std::unique_ptr< PersistentKVP > m_pers_kvp_store;
+
+    bool m_path_jump_in_progress;
+    std::string m_path_jump_last_filter;
+
+    std::unique_ptr< PrefixDB > m_pdb;
 };
 
 #endif
