@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2012 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,8 +27,8 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 994
-#define CATCOMENTRY 62
+#define CATENTRY 1039
+#define CATCOMENTRY 63
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -423,7 +423,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[364]=dupstring( "" );
   catalog[365]=dupstring( "Sorry, there is no such font!" );
   catalog[366]=dupstring( "" );
-  catalog[367]=dupstring( "The file %s isn't a worker configuration file!|Using default configuration..." );
+  catalog[367]=dupstring( "" );
   catalog[368]=dupstring( "Clock bar settings" );
   catalog[369]=dupstring( "Clock bar mode:" );
   catalog[370]=dupstring( "Show current time and free RAM/Swap (on GNU/Linux)" );
@@ -440,7 +440,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[381]=dupstring( "Enter own font (with X name)" );
   catalog[382]=dupstring( "Font example" );
   catalog[383]=dupstring( "X font name:" );
-  catalog[384]=dupstring( "The configuration file is from a newer Worker version and cannot be loaded!|Please update at least to version %d.%d.%d.|I will continue with the default configuration." );
+  catalog[384]=dupstring( "" );
   catalog[385]=dupstring( "Reset directory sizes" );
   catalog[386]=dupstring( "Use <DIR> for unknown dir sizes" );
   catalog[387]=dupstring( "Activate shortkey" );
@@ -456,7 +456,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[397]=dupstring( "Import" );
   catalog[398]=dupstring( "Export" );
   catalog[399]=dupstring( "Changes made here only affect the exported configuration|not your real configuration!" );
-  catalog[400]=dupstring( "File %s isn't a valid worker export file!" );
+  catalog[400]=dupstring( "" );
   catalog[401]=dupstring( "configure buttons to export" );
   catalog[402]=dupstring( "configure hotkeys to export" );
   catalog[403]=dupstring( "configure file types to export" );
@@ -469,7 +469,7 @@ void WorkerLocale::initBuiltinLang()
   catalog[410]=dupstring( "Export to %s finished." );
   catalog[411]=dupstring( "Can't open %s for writing, please select another file" );
   catalog[412]=dupstring( "%s isn't a file!" );
-  catalog[413]=dupstring( "Export file is from a newer worker version!|Update at least to version %d.%d.%d to use it." );
+  catalog[413]=dupstring( "" );
   catalog[414]=dupstring( "The configuration contains %d button bank(s), %d hotkey(s) and %d file type(s).|You can now change these parts before importing them." );
   catalog[415]=dupstring( "Please enter the file name to import from." );
   catalog[416]=dupstring( "You can change the import configuration before|the selected parts will be imported." );
@@ -758,7 +758,7 @@ if you have the ssh_askpass tool. Do you really want to continue?" );
   catalog[662]=dupstring( "Select method:" );
   catalog[663]=dupstring( "Normal (click toggles select state)" );
   catalog[664]=dupstring( "Alternative (click selects element and deselects all other)" );
-  catalog[665]=dupstring( "This version of Worker can't read your configuration from a Worker 1.x version.|If you still want to use it you should temporary install Worker 2.11.1 or older|which can import your configuration." );
+  catalog[665]=dupstring( "" );
   catalog[666]=dupstring( "Do you want to cancel the delete operation?" );
   catalog[667]=dupstring( "Abort deletion" );
   catalog[668]=dupstring( "Continue deletion" );
@@ -832,7 +832,7 @@ match any font." );
   catalog[727]=dupstring( "Search content of archives too" );
   catalog[728]=dupstring( "Start new search - F5" );
   catalog[729]=dupstring( "File name" );
-  catalog[730]=dupstring( "Change directory to entry" );
+  catalog[730]=dupstring( "Change directory to entry - F1" );
   catalog[731]=dupstring( "View - F3" );
   catalog[732]=dupstring( "Edit - F4" );
   catalog[733]=dupstring( "Remove selected results from list" );
@@ -1096,6 +1096,51 @@ match any font." );
   catalog[991]=dupstring( "Watch directories for changes" );
   catalog[992]=dupstring( "There is not enough space on target %s.|Free space is %s. Still continuing?" );
   catalog[993]=dupstring( "Command %s not found" );
+  catalog[994]=dupstring( "" );
+  catalog[995]=dupstring( "Panelize - F2" );
+  catalog[996]=dupstring( "Panelize (keep window)" );
+  catalog[997]=dupstring( "Switch mode" );
+  catalog[998]=dupstring( "Configure mode" );
+  catalog[999]=dupstring( "Appy dialog type to X windows" );
+  catalog[1000]=dupstring( "Command not supported" );
+  catalog[1001]=dupstring( "Flags without path are relative to base dir" );
+  catalog[1002]=dupstring( "The target directory is a virtual directory. If you continue,|the files will be copied to|%s." );
+  catalog[1003]=dupstring( "Match directories too" );
+  catalog[1004]=dupstring( "Menu entries" );
+  catalog[1005]=dupstring( "bank %d" );
+  catalog[1006]=dupstring( "Paths" );
+  catalog[1007]=dupstring( "Command menu: You can browse the entries with cursor keys, enter categories with right key.\nYou can enter a filter to quickly find a matching entry." );
+  catalog[1008]=dupstring( "Current sub-tree:" );
+  catalog[1009]=dupstring( "Element name:" );
+  catalog[1010]=dupstring( "Assigned command:" );
+  catalog[1011]=dupstring( "Reading directory content..." );
+  catalog[1012]=dupstring( "A configuration update to version %d.%d.%d has been found.|You can decide to import the new elements or skip this update.|The update contains %%d button bank(s), %%d hotkey(s) and %%d file type(s).|You can now also change these parts before importing them." );
+  catalog[1013]=dupstring( "Use MIME description" );
+  catalog[1014]=dupstring( "Assigned shortkey:" );
+  catalog[1015]=dupstring( "Activate search mode in key press" );
+  catalog[1016]=dupstring( "List view modes" );
+  catalog[1017]=dupstring( "switch to normal mode" );
+  catalog[1018]=dupstring( "switch to virtual dir mode" );
+  catalog[1019]=dupstring( "switch to show image mode" );
+  catalog[1020]=dupstring( "switch to information mode" );
+  catalog[1021]=dupstring( "switch to text view mode" );
+  catalog[1022]=dupstring( "open configuration of current mode" );
+  catalog[1023]=dupstring( "Registered commands" );
+  catalog[1024]=dupstring( "directory view" );
+  catalog[1025]=dupstring( "virtual directory" );
+  catalog[1026]=dupstring( "Directory mode" );
+  catalog[1027]=dupstring( "inactive" );
+  catalog[1028]=dupstring( "active (release with Ctrl-0)" );
+  catalog[1029]=dupstring( "Hold status:" );
+  catalog[1030]=dupstring( "Hold filter:" );
+  catalog[1031]=dupstring( "Entries" );
+  catalog[1032]=dupstring( "Key to hold entries" );
+  catalog[1033]=dupstring( "You can hold the currently visible entries and refine the search with a new filter. You can press Ctrl 1 to 9 to hold the entries corresponding to their match level. Ctrl 1 will only keep the best matches, Ctrl 2 also the second best matches, and so on. You can also double click on the the entry in the right list view. To release the held entries, press Ctrl 0 or click on the 'active' button." );
+  catalog[1034]=dupstring( "Panelize" );
+  catalog[1035]=dupstring( "Command history:" );
+  catalog[1036]=dupstring( "true if entry is a broken symlink" );
+  catalog[1037]=dupstring( "Do you really want to delete all selected file types|and its sub-types?" );
+  catalog[1038]=dupstring( "Select registered command:" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1161,6 +1206,7 @@ match any font." );
   catalogcom[59]=dupstring( "Switch button bank" );
   catalogcom[60]=dupstring( "Path Jump" );
   catalogcom[61]=dupstring( "Copy string to clipboard" );
+  catalogcom[62]=dupstring( "Command menu" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
